==> klayout_0.28.15.orig.tar.gz: klayout-0.28.15/scripts/mkqtdecl5/QtNetwork/allofqt.cpp <==
#include "QtNetwork/QAbstractNetworkCache"
#include "QtNetwork/QAbstractSocket"
#include "QtNetwork/QAuthenticator"
#include "QtNetwork/QDnsDomainNameRecord"
#include "QtNetwork/QDnsHostAddressRecord"
#include "QtNetwork/QDnsLookup"
#include "QtNetwork/QDnsMailExchangeRecord"
#include "QtNetwork/QDnsServiceRecord"
#include "QtNetwork/QDnsTextRecord"
#include "QtNetwork/QHostAddress"
#include "QtNetwork/QHostInfo"
#include "QtNetwork/QHttpMultiPart"
#include "QtNetwork/QHttpPart"
#include "QtNetwork/Q_IPV6ADDR"
#include "QtNetwork/QIPv6Address"
#include "QtNetwork/QLocalServer"
#include "QtNetwork/QLocalSocket"
#include "QtNetwork/QNetworkAccessManager"
#include "QtNetwork/QNetworkAddressEntry"
#include "QtNetwork/QNetworkCacheMetaData"
#include "QtNetwork/QNetworkConfiguration"
#include "QtNetwork/QNetworkConfigurationManager"
#include "QtNetwork/QNetworkCookie"
#include "QtNetwork/QNetworkCookieJar"
#include "QtNetwork/QNetworkDiskCache"
#include "QtNetwork/QNetworkInterface"
#include "QtNetwork/QNetworkProxy"
#include "QtNetwork/QNetworkProxyFactory"
#include "QtNetwork/QNetworkProxyQuery"
#include "QtNetwork/QNetworkReply"
#include "QtNetwork/QNetworkRequest"
#include "QtNetwork/QNetworkSession"
#include "QtNetwork/QSsl"
#include "QtNetwork/QSslCertificate"
#include "QtNetwork/QSslCertificateExtension"
#include "QtNetwork/QSslCipher"
#include "QtNetwork/QSslConfiguration"
#include "QtNetwork/QSslEllipticCurve"
#include "QtNetwork/QSslError"
#include "QtNetwork/QSslKey"
#include "QtNetwork/QSslPreSharedKeyAuthenticator"
#include "QtNetwork/QSslSocket"
#include "QtNetwork/QTcpServer"
#include "QtNetwork/QTcpSocket"
#include "QtNetwork/QtNetwork"
#include "QtNetwork/QtNetworkDepends"
#include "QtNetwork/QtNetworkVersion"
#include "QtNetwork/QUdpSocket"

==> klayout-0.29.12.tar.gz: klayout-0.29.12/scripts/mkqtdecl5/QtNetwork/allofqt.cpp <==
#include "QtNetwork/QAbstractNetworkCache"
#include "QtNetwork/QAbstractSocket"
#include "QtNetwork/QAuthenticator"
#include "QtNetwork/QDnsDomainNameRecord"
#include "QtNetwork/QDnsHostAddressRecord"
#include "QtNetwork/QDnsLookup"
#include "QtNetwork/QDnsMailExchangeRecord"
#include "QtNetwork/QDnsServiceRecord"
#include "QtNetwork/QDnsTextRecord"
#include "QtNetwork/QDtls"
#include "QtNetwork/QDtlsClientVerifier"
#include "QtNetwork/QHostAddress"
#include "QtNetwork/QHostInfo"
#include "QtNetwork/QHstsPolicy"
#include "QtNetwork/QHttpMultiPart"
#include "QtNetwork/QHttpPart"
#include "QtNetwork/Q_IPV6ADDR"
#include "QtNetwork/QIPv6Address"
#include "QtNetwork/QLocalServer"
#include "QtNetwork/QLocalSocket"
#include "QtNetwork/QNetworkAccessManager"
#include "QtNetwork/QNetworkAddressEntry"
#include "QtNetwork/QNetworkCacheMetaData"
#include "QtNetwork/QNetworkConfiguration"
#include "QtNetwork/QNetworkConfigurationManager"
#include "QtNetwork/QNetworkCookie"
#include "QtNetwork/QNetworkCookieJar"
#include "QtNetwork/QNetworkDatagram"
#include "QtNetwork/QNetworkDiskCache"
#include "QtNetwork/QNetworkInterface"
#include "QtNetwork/QNetworkProxy"
#include "QtNetwork/QNetworkProxyFactory"
#include "QtNetwork/QNetworkProxyQuery"
#include "QtNetwork/QNetworkReply"
#include "QtNetwork/QNetworkRequest"
#include "QtNetwork/QNetworkSession"
#include "QtNetwork/QSctpServer"
#include "QtNetwork/QSctpSocket"
#include "QtNetwork/QSsl"
#include "QtNetwork/QSslCertificate"
#include "QtNetwork/QSslCertificateExtension"
#include "QtNetwork/QSslCipher"
#include "QtNetwork/QSslConfiguration"
#include "QtNetwork/QSslDiffieHellmanParameters"
#include "QtNetwork/QSslEllipticCurve"
#include "QtNetwork/QSslError"
#include "QtNetwork/QSslKey"
#include "QtNetwork/QSslPreSharedKeyAuthenticator"
#include "QtNetwork/QSslSocket"
#include "QtNetwork/QTcpServer"
#include "QtNetwork/QTcpSocket"
#include "QtNetwork/QtNetwork"
#include "QtNetwork/QtNetworkDepends"
#include "QtNetwork/QtNetworkVersion"
#include "QtNetwork/QUdpSocket"
